@@ -60,9 +60,9 @@ def wf_bandstructure2D(structure, c=None):
 
     mpr2d = MPRelaxSet2D(structure, force_gamma=True)
     fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
-    fws.append(StaticFW(parents=fws[0]))
-    fws.append(NonSCFFW(parents=fws[1], mode='uniform'))
-    fws.append(NonSCFFW(parents=fws[1], mode='line'))
+    fws.append(StaticFW(parents=0))
+    fws.append(NonSCFFW(parents=1, mode='uniform'))
+    fws.append(NonSCFFW(parents=1, mode='line'))
     wf = Workflow(fws)
     '''check bandstructure.yaml'''
     '''
